@@ -10,15 +10,15 @@
 
 print.CTLobject <- function(x, ...){
   cat("CTLobject summary\n\n")
-  cat("- Number of scanned phenotypes:",length(x),"\n")
+  cat("- Number of scanned phenotypes:", length(x), "\n")
 }
 
 print.CTLscan <- function(x, ...){
   if(missing(x)) stop("argument 'x' is missing, with no default")
   cat("CTLscan summary",attr(x$ctl,"name"),"\n\n")
-  cat("- Number of background phenotypes",dim(x$ctl)[1],"\n")
-  cat("- Number of markers",dim(x$ctl)[2],"\n")
-  cat("- Number of permutations",length(unlist(x$p)),"\n")
+  cat("- Number of background phenotypes:",  dim(x$ctl)[2], "\n")
+  cat("- Number of markers:", dim(x$ctl)[1], "\n")
+  cat("- Number of permutations:", length(unlist(x$p)), "\n")
   invisible(CTLsignificant(x))
 }
 
