@@ -7,12 +7,11 @@
 # 
 
 #Create the 2 possible CTL matrices: 1) phenotypes versus markers (PxM) and 2) Phenotypes versus phenotypes (PxP)
-CTLprofiles <- function(CTLobject, against = c("markers","phenotypes"), significance=0.05, verbose=FALSE, warn = TRUE){
+CTLprofiles <- function(CTLobject, against = c("markers","phenotypes"), significance = 0.05, verbose = FALSE) {
   if(missing(CTLobject)) stop("argument 'CTLobject' is missing, with no default")
   mymatrix <- NULL
   mynames <- NULL
-  warn <- warn
-  notice <- TRUE
+
   for(p in 1:length(CTLobject)){
     lod <- CTLtoLODvector(CTLobject[[p]], against)
     threshold <- -log10(significance)
@@ -21,7 +20,8 @@ CTLprofiles <- function(CTLobject, against = c("markers","phenotypes"), signific
       mynames <- c(mynames,ctl.name(CTLobject[[p]]))  
     }
   }
-  if(is.null(mymatrix)){ cat('No significant')
+  if(is.null(mymatrix)) { 
+    cat("No significant CTLs detected at alpha = ", significance,"\n")
     return(NULL);
   }
   rownames(mymatrix) <- mynames
@@ -34,3 +34,4 @@ CTLprofiles <- function(CTLobject, against = c("markers","phenotypes"), signific
 }
 
 # end of ctl.profiles.R
+
